@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025  Dimas Firmansyah
 
 ;; Author: Dimas Firmansyah <deirn@bai.lol>
-;; Package-Version: 20260107.1801
-;; Package-Revision: 47b6e24820fb
+;; Package-Version: 20260209.1847
+;; Package-Revision: fe149182385e
 ;; Homepage: https://github.com/deirn/mason.el
 ;; Package-Requires: ((emacs "30.1") (s "1.13.0"))
 ;; Keywords: tools lsp installer
@@ -270,22 +270,20 @@ To be used with `mason--process' and `mason--process-sync'."
 (defun mason--update-target (then)
   "Update target and call THEN."
   (let* ((reg-dir (mason--expand-child-file-name "registry" mason-dir))
-         (out-file (mason--expand-child-file-name "target" reg-dir))
-         output)
+         (out-file (mason--expand-child-file-name "target" reg-dir)))
     (when (file-exists-p out-file)
       (setq mason--target (ignore-errors (mason--read-data out-file))))
     (if (not (null mason--target))
         (funcall then)
       (mason--process
-        (mason--emacs-cmd '(message "%S" (mason--get-target)))
-        :filter (lambda (_ o) (setq output (concat output o)))
+        (mason--emacs-cmd
+          `(make-directory ,reg-dir t)
+          `(with-temp-file ,out-file
+             (prin1 (mason--get-target) (current-buffer))))
         :then
         (lambda (success)
           (if (not success) (error "Updating target failed")
-            (setq mason--target (read output))
-            (make-directory reg-dir t)
-            (with-temp-file out-file
-              (insert output))
+            (setq mason--target (mason--read-data out-file))
             (funcall then)))))))
 
 (defun mason--target-match (str)
